/* Copyright 2000 - 2002 Rational Software Corporation. All Rights Reserved.
 * This software contains proprietary and confidential information of Rational
 * and its suppliers. Use, disclosure or reproduction is prohibited
 * without the prior express written consent of Rational.
 */

#ifndef _TSEA_H_
#define _TSEA_H_

#include <rttypes.h>

/*
 * Programming Tip
 *
 * If you are creating a TSEA DLL for Windows then you should define the macro
 * TSEAENTRYPOINTEXPORT when compiling the source code, either on the compiler
 * command line or within the source files.  This causes the TSEA entry points
 * to be exported from the DLL when the object files are linked to make the
 * DLL.  Linking is simplified because a separate .def file is not needed.
 *
 * In normal operation only TSEE references a TSEA DLL.  It does so by using
 * the dlopen family of functions since it may need to load several DLLs and
 * individual DLLs may not implement the optional entry points.  Consequently,
 * TSEE does not define the TSEAENTRYPOINTEXPORT macro during compilation.
 */

#if defined(_WIN32) || defined(__WIN32__)
#if defined(TSEAENTRYPOINTEXPORT)
#if TSEAENTRYPOINTEXPORT
#define TSEAENTRYPOINT __declspec(dllexport)
#else	/* DLL consumer, typically not used (see above) */
#define TSEAENTRYPOINT __declspec(dllimport)
#endif
#else	/* Windows legacy definition for compatibility */
#define TSEAENTRYPOINT extern
#endif
#else	/* Non-Windows platform */
#define TSEAENTRYPOINT extern
#endif

/*
 * Return codes
 */

#define TSEA_NOOP	 1
#define TSEA_OK		 0
#define TSEA_FAIL	-1
#define TSEA_SYSERROR	-2
#define TSEA_BADHANDLE	-99	/* session/task handle does not exist */

/*
 * Constants and Type Definitions
 */
#define ERRMSGSZ 4096			/* Size of TSEAError message buf */

typedef void *SessionHandle;
typedef void *TaskHandle;
typedef char *TaskType;

/*
 * Function prototypes
 */

#ifdef __cplusplus
extern "C" {
#endif

/* Reserved for future use -- not implemented */
TSEAENTRYPOINT s32 AdaptorInit();
TSEAENTRYPOINT s32 AdaptorExit();

/* Required entry points */
TSEAENTRYPOINT SessionHandle SessionOpen(char *host, u16 port, s32 strandId,
	char **message);
TSEAENTRYPOINT s32 SessionClose(SessionHandle session);
TSEAENTRYPOINT s32 SessionGetOption(SessionHandle session, TaskType type,
	char *optname, void *optval, s32 *len);
TSEAENTRYPOINT s32 SessionSetOption(SessionHandle session, TaskType type,
	char *optname, void *optval, s32 len);

TSEAENTRYPOINT TaskHandle TaskCreate(SessionHandle session, TaskType type,
	char *sourceLocation, char *testScriptId);
TSEAENTRYPOINT s32 TaskClose(TaskHandle task);
TSEAENTRYPOINT s32 TaskGetOption(TaskHandle task, char *optname, void *optval,
	s32 *len);
TSEAENTRYPOINT s32 TaskSetOption(TaskHandle task, char *optname, void *optval,
	s32 len);
TSEAENTRYPOINT s32 TaskExecute(TaskHandle task);
TSEAENTRYPOINT s32 TaskAbort(TaskHandle task);

TSEAENTRYPOINT s32 TSEAError(SessionHandle session, char **message);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* _TSEA_H_ */
